@@ -251,10 +251,6 @@ WORKFLOW_TASKS_EXCLUSIONS = [
 ]
 
 
-ANSIBLE_TASKS_YAMLS = [
-    './extraconfig/pre_network/boot_param_tasks.yaml'
-]
-
 HEAT_OUTPUTS_EXCLUSIONS = [
     './puppet/extraconfig/tls/ca-inject.yaml',
     './deployed-server/deployed-server.yaml',
@@ -276,7 +272,7 @@ def to_camel_case(string):
 def get_base_endpoint_map(filename):
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
         return tpl['parameters']['EndpointMap']['default']
     except Exception:
         print(traceback.format_exc())
@@ -286,7 +282,7 @@ def get_base_endpoint_map(filename):
 def get_endpoint_map_from_env(filename):
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
         return {
             'file': filename,
             'map': tpl['parameter_defaults']['EndpointMap']
@@ -302,7 +298,7 @@ def validate_endpoint_map(base_map, env_map):
 
 def validate_role_name(filename):
     with open(filename, 'r') as f:
-        tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     role_data = tpl[0]
     if role_data['name'] != os.path.basename(filename).split('.')[0]:
@@ -318,7 +314,7 @@ def validate_hci_compute_services_default(env_filename, env_tpl):
     roles_filename = os.path.join(os.path.dirname(env_filename),
                                   '../roles/Compute.yaml')
     with open(roles_filename, 'r') as f:
-        roles_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        roles_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     for role in roles_tpl:
         if role['name'] == 'Compute':
@@ -334,7 +330,7 @@ def validate_hci_computehci_role(hci_role_filename, hci_role_tpl):
     compute_role_filename = os.path.join(os.path.dirname(hci_role_filename),
                                          './Compute.yaml')
     with open(compute_role_filename, 'r') as f:
-        compute_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     compute_role_services = compute_role_tpl[0]['ServicesDefault']
     for role in hci_role_tpl:
@@ -352,7 +348,7 @@ def validate_controller_dashboard(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -365,13 +361,30 @@ def validate_controller_dashboard(filename, tpl):
     return 0
 
 
+def validate_controller_storage_nfs(filename, tpl, exclude_service=()):
+    control_role_filename = os.path.join(os.path.dirname(filename),
+                                         './Controller.yaml')
+    with open(control_role_filename, 'r') as f:
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+
+    control_role_services = control_role_tpl[0]['ServicesDefault']
+    for role in tpl:
+        if role['name'] == 'ControllerStorageNfs':
+            services = [x for x in role['ServicesDefault'] if (x not in exclude_service)]
+            if sorted(services) != sorted(control_role_services):
+                print('ERROR: ServicesDefault in %s is different from '
+                      'ServicesDefault in roles/Controller.yaml' % filename)
+                return 1
+    return 0
+
+
 def validate_hci_role(hci_role_filename, hci_role_tpl):
     role_files = ['HciCephAll', 'HciCephFile', 'HciCephMon', 'HciCephObject']
     if hci_role_filename in ['./roles/' + x + '.yaml' for x in role_files]:
         compute_role_filename = \
             os.path.join(os.path.dirname(hci_role_filename), './Compute.yaml')
         with open(compute_role_filename, 'r') as f:
-            compute_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         compute_role_services = compute_role_tpl[0]['ServicesDefault']
         for role in hci_role_tpl:
@@ -410,7 +423,7 @@ def validate_ceph_role(ceph_role_filename, ceph_role_tpl):
         ceph_storage_role_filename = \
             os.path.join(os.path.dirname(ceph_role_filename), './CephStorage.yaml')
         with open(ceph_storage_role_filename, 'r') as f:
-            ceph_storage_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            ceph_storage_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         ceph_storage_role_services = ceph_storage_role_tpl[0]['ServicesDefault']
         for role in ceph_role_tpl:
@@ -441,7 +454,7 @@ def validate_controller_no_ceph_role(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -465,7 +478,7 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     with open(cmpt_filename, 'r') as f:
-        cmpt_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        cmpt_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     cmpt_services = cmpt_tpl[0]['ServicesDefault']
     cmpt_services = [x for x in cmpt_services if (x not in exclude_service)]
@@ -601,7 +614,7 @@ def validate_docker_service_mysql_usage(filename, tpl):
                 newfilename = \
                     os.path.normpath(os.path.join(os.path.dirname(incfile), f))
                 with open(newfilename, 'r') as newfile:
-                    newtmp = yaml.load(newfile.read(), Loader=yaml.FullLoader)
+                    newtmp = yaml.load(newfile.read(), Loader=yaml.SafeLoader)
                 read_all(newfile, newtmp)
 
     read_all(filename, tpl)
@@ -1056,7 +1069,7 @@ def validate(filename, param_map):
     retval = 0
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         is_heat_template = 'heat_template_version' in tpl
 
@@ -1112,6 +1125,14 @@ def validate(filename, param_map):
                 filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
             retval |= validate_hci_computehci_role(filename, tpl)
 
+        if filename.startswith('./roles/ControllerStorageNfs.yaml'):
+            exclude = [
+                'OS::TripleO::Services::CephNfs']
+            retval |= validate_controller_storage_nfs(filename, tpl, exclude)
+
+        if filename.startswith('./roles/ControllerStorageDashboard.yaml'):
+            retval |= validate_controller_dashboard(filename, tpl)
+
         if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
                 filename.startswith('./roles/ComputeSriov.yaml') or \
                 filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
@@ -1164,8 +1185,6 @@ def validate(filename, param_map):
             retval |= validate_nic_config_file(filename, tpl)
 
     except Exception:
-        if filename in ANSIBLE_TASKS_YAMLS:
-            return 0
         print(traceback.format_exc())
         return 1
     # yaml is OK, now walk the parameters and output a warning for unused ones
@@ -1242,11 +1261,11 @@ def validate_upgrade_tasks(upgrade_tasks):
 def validate_network_data_file(data_file_path):
     try:
         with open(data_file_path, 'r') as data_file:
-            data_file = yaml.load(data_file.read(), Loader=yaml.FullLoader)
+            data_file = yaml.load(data_file.read(), Loader=yaml.SafeLoader)
 
         base_file_path = os.path.dirname(data_file_path) + "/network_data.yaml"
         with open(base_file_path, 'r') as base_file:
-            base_file = yaml.load(base_file.read(), Loader=yaml.FullLoader)
+            base_file = yaml.load(base_file.read(), Loader=yaml.SafeLoader)
 
         retval = 0
         for n in base_file:
